@@ -21,6 +21,7 @@ from autots.models.model_list import (
     recombination_approved,
     no_shared,
     superfast,
+    model_lists,
 )
 from itertools import zip_longest
 from autots.models.basics import (
@@ -47,6 +48,7 @@ from autots.models.statsmodels import (
     ARDL,
     DynamicFactorMQ,
 )
+from autots.models.arch import ARCH
 
 
 def create_model_id(
@@ -487,6 +489,29 @@ def ModelMonster(
             verbose=verbose,
             **parameters,
         )
+    elif model == 'PytorchForecasting':
+        from autots.models.pytorch import PytorchForecasting
+
+        return PytorchForecasting(
+            frequency=frequency,
+            prediction_interval=prediction_interval,
+            holiday_country=holiday_country,
+            random_seed=random_seed,
+            verbose=verbose,
+            forecast_length=forecast_length,
+            **parameters,
+        )
+    elif model == 'ARCH':
+        return ARCH(
+            frequency=frequency,
+            prediction_interval=prediction_interval,
+            holiday_country=holiday_country,
+            random_seed=random_seed,
+            verbose=verbose,
+            forecast_length=forecast_length,
+            n_jobs=n_jobs,
+            **parameters,
+        )
     else:
         raise AttributeError(
             ("Model String '{}' not a recognized model type").format(model)
@@ -1479,6 +1504,22 @@ def TemplateWizard(
     return template_result
 
 
+def model_list_to_dict(model_list):
+    """Convert various possibilities to dict."""
+    if model_list in list(model_lists.keys()):
+        model_list = model_lists[model_list]
+
+    if isinstance(model_list, dict):
+        model_prob = list(model_list.values())
+        model_list = [*model_list]
+    elif isinstance(model_list, list):
+        trs_len = len(model_list)
+        model_prob = [1 / trs_len] * trs_len
+    else:
+        raise ValueError("model_list type not recognized.")
+    return model_list, model_prob
+
+
 def RandomTemplate(
     n: int = 10,
     model_list: list = [
@@ -1503,12 +1544,14 @@ def RandomTemplate(
     template = pd.DataFrame()
     counter = 0
     n_models = len(model_list)
-    while len(template.index) < n:
+    model_list, model_prob = model_list_to_dict(model_list)
+    template_list = []
+    while len(template_list) < n:
         # this assures all models get choosen at least once
         if counter < n_models:
             model_str = model_list[counter]
         else:
-            model_str = random.choices(model_list)[0]
+            model_str = random.choices(model_list, model_prob, k=1)[0]
         param_dict = ModelMonster(model_str).get_new_params(method=models_mode)
         if counter % 4 == 0:
             trans_dict = RandomTransform(
@@ -1521,20 +1564,22 @@ def RandomTemplate(
                 transformer_list=transformer_list,
                 transformer_max_depth=transformer_max_depth,
             )
-        row = pd.DataFrame(
-            {
-                'Model': model_str,
-                'ModelParameters': json.dumps(param_dict),
-                'TransformationParameters': json.dumps(trans_dict),
-                'Ensemble': 0,
-            },
-            index=[0],
+        template_list.append(
+            pd.DataFrame(
+                {
+                    'Model': model_str,
+                    'ModelParameters': json.dumps(param_dict),
+                    'TransformationParameters': json.dumps(trans_dict),
+                    'Ensemble': 0,
+                },
+                index=[0],
+            )
         )
-        template = pd.concat([template, row], axis=0, ignore_index=True)
-        template.drop_duplicates(inplace=True)
         counter += 1
         if counter > (n * 3):
             break
+    template = pd.concat(template_list, axis=0, ignore_index=True)
+    template = template.drop_duplicates()
     return template
 
 
@@ -1605,13 +1650,17 @@ def _trans_dicts(
     n: int = 5,
     transformer_list: dict = {},
     transformer_max_depth: int = 8,
+    first_transformer: dict = None,
 ):
-    fir = json.loads(current_ops.iloc[0, :]['TransformationParameters'])
+    if first_transformer is None:
+        first_transformer = json.loads(
+            current_ops.iloc[0, :]['TransformationParameters']
+        )
     cur_len = current_ops.shape[0]
     if cur_len > 1:
-        # select randomly from best of data, doesn't handle lengths < 2
-        top_r = np.floor((cur_len / 5) + 2)
-        r_id = np.random.randint(1, top_r)
+        # select randomly from best of data
+        top_r = cur_len - 1 if cur_len < 6 else int(cur_len / 3)
+        r_id = random.randint(0, top_r)
         sec = json.loads(current_ops.iloc[r_id, :]['TransformationParameters'])
     else:
         sec = RandomTransform(
@@ -1632,7 +1681,7 @@ def _trans_dicts(
             transformer_list=transformer_list,
             transformer_max_depth=transformer_max_depth,
         )
-    arr = [fir, sec, best, r, r2]
+    arr = [first_transformer, sec, best, r, r2]
     trans_dicts = [json.dumps(trans_dict_recomb(arr)) for _ in range(n)]
     return trans_dicts
 
@@ -1640,7 +1689,7 @@ def _trans_dicts(
 def NewGeneticTemplate(
     model_results,
     submitted_parameters,
-    sort_column: str = "smape_weighted",
+    sort_column: str = "Score",
     sort_ascending: bool = True,
     max_results: int = 50,
     max_per_model_class: int = 5,
@@ -1654,82 +1703,136 @@ def NewGeneticTemplate(
     transformer_list: dict = {},
     transformer_max_depth: int = 8,
     models_mode: str = "default",
+    score_per_series=None,
 ):
     """
     Return new template given old template with model accuracies.
 
+    "No mating!" - Pattern, Sanderson
+
     Args:
         model_results (pandas.DataFrame): models that have actually been run
         submitted_paramters (pandas.DataFrame): models tried (may have returned different parameters to results)
 
     """
-    new_template = pd.DataFrame()
+    new_template_list = []
 
     # filter existing templates
-    sorted_results = model_results[model_results['Ensemble'] == 0].copy()
+    sorted_results = model_results[
+        (model_results['Ensemble'] == 0) & (model_results['Exceptions'].isna())
+    ].copy()
+    # remove duplicates by exact same performance
+    sorted_results = sorted_results.sort_values(
+        by="TotalRuntimeSeconds", ascending=True
+    )
+    sorted_results.drop_duplicates(
+        subset=['ValidationRound', 'smape', 'mae', 'spl'], keep="first", inplace=True
+    )
+    sorted_results = sorted_results.drop_duplicates(subset=template_cols, keep='first')
+    # perform selection
     sorted_results = sorted_results.sort_values(
         by=sort_column, ascending=sort_ascending, na_position='last'
     )
-    sorted_results = sorted_results.drop_duplicates(subset=template_cols, keep='first')
+    # find some of the best per series models to mix in
+    if score_per_series is not None:
+        per_s = score_per_series / (score_per_series.min(axis=0) + 1)
+        ad_mods = per_s.quantile(0.3, axis=1).nsmallest(3).index.tolist()
+        ad_mods1 = sorted_results[sorted_results["ID"].isin(ad_mods)]
+        ad_mods = per_s.quantile(0.1, axis=1).nsmallest(3).index.tolist()
+        ad_mods2 = sorted_results[sorted_results["ID"].isin(ad_mods)]
+    # take only max of n models per model type to reduce duplication of similar
     if str(max_per_model_class).isdigit():
         sorted_results = (
             sorted_results.sort_values(sort_column, ascending=sort_ascending)
             .groupby('Model')
             .head(max_per_model_class)
-            .reset_index()
         )
-    sorted_results = sorted_results.sort_values(
-        by=sort_column, ascending=sort_ascending, na_position='last'
-    ).head(top_n)
+        """
+        sorted_results = (
+            sorted_results
+            .groupby('Model')
+            .sample(max_per_model_class, weights=((1 + (1 / sorted_results['Score'])) ** 10) - 1)
+        )
+        """
+    # take only n results to proceed
+    sorted_results = sorted_results.head(top_n)
+    # tack on the per_series best afterwards
+    if score_per_series is not None:
+        sorted_results = pd.concat(
+            [sorted_results, ad_mods1, ad_mods2], axis=0
+        ).drop_duplicates(subset=template_cols, keep='first')
 
-    # borrow = ['ComponentAnalysis']
     best = json.loads(sorted_results.iloc[0, :]['TransformationParameters'])
 
-    for model_type in sorted_results['Model'].unique():
+    # best models make more kids
+    n_list = sorted([1, 2, 3] * int((sorted_results.shape[0] / 3) + 1), reverse=True)
+    counter = 0
+    # begin the breeding
+    sidx = {name: i for i, name in enumerate(list(sorted_results), start=1)}
+    for row in sorted_results.itertuples(name=None):
+        n = n_list[counter]
+        counter += 1
+        model_type = row[sidx["Model"]]
+        model_params = row[sidx["ModelParameters"]]
+        try:
+            trans_params = json.loads(row[sidx["TransformationParameters"]])
+        except Exception as e:
+            raise ValueError(f"JSON didn't like {row}") from e
+        current_ops = sorted_results[sorted_results['Model'] == model_type]
+        # only transformers for some models
         if model_type in no_params:
-            current_ops = sorted_results[sorted_results['Model'] == model_type]
-            n = 3
             trans_dicts = _trans_dicts(
                 current_ops,
                 best=best,
                 n=n,
                 transformer_list=transformer_list,
                 transformer_max_depth=transformer_max_depth,
+                first_transformer=trans_params,
             )
-            model_param = current_ops.iloc[0, :]['ModelParameters']
-            new_row = pd.DataFrame(
-                {
-                    'Model': model_type,
-                    'ModelParameters': model_param,
-                    'TransformationParameters': trans_dicts,
-                    'Ensemble': 0,
-                },
-                index=list(range(n)),
+            new_template_list.append(
+                pd.DataFrame(
+                    {
+                        'Model': model_type,
+                        'ModelParameters': model_params,
+                        'TransformationParameters': trans_dicts,
+                        'Ensemble': 0,
+                    },
+                    index=list(range(n)),
+                )
             )
+        # recombination for models where mixing params is allowable
         elif model_type in recombination_approved:
-            current_ops = sorted_results[sorted_results['Model'] == model_type]
-            n = 4
             trans_dicts = _trans_dicts(
                 current_ops,
                 best=best,
                 n=n,
                 transformer_list=transformer_list,
                 transformer_max_depth=transformer_max_depth,
+                first_transformer=trans_params,
             )
             # select the best model of this type
-            fir = json.loads(current_ops.iloc[0, :]['ModelParameters'])
+            # fir = json.loads(current_ops.iloc[0, :]['ModelParameters'])
+            fir = json.loads(model_params)
             cur_len = current_ops.shape[0]
+            # select randomly from best of data
             if cur_len > 1:
-                # select randomly from best of data, doesn't handle lengths < 2
-                top_r = np.floor((cur_len / 5) + 2)
-                r_id = np.random.randint(1, top_r)
+                top_r = cur_len - 1 if cur_len < 9 else int(cur_len / 3)
+                r_id = random.randint(0, top_r)
                 sec = json.loads(current_ops.iloc[r_id, :]['ModelParameters'])
             else:
                 sec = ModelMonster(model_type).get_new_params(method=models_mode)
+            # select weighted from all
+            if cur_len > 4:
+                r = json.loads(
+                    current_ops['ModelParameters']
+                    .sample(1, weights=np.log(np.arange(cur_len) + 1)[::-1])
+                    .iloc[0]
+                )
+            else:
+                r = ModelMonster(model_type).get_new_params(method=models_mode)
             # generate new random parameters ('mutations')
-            r = ModelMonster(model_type).get_new_params(method=models_mode)
             r2 = ModelMonster(model_type).get_new_params(method=models_mode)
-            arr = [fir, sec, r2, r]
+            arr = np.array([fir, sec, r2, r])
             model_dicts = list()
             # recombine best and random to create new generation
             for _ in range(n):
@@ -1738,41 +1841,46 @@ def NewGeneticTemplate(
                 b = r_sel[1]
                 c = dict_recombination(a, b)
                 model_dicts.append(json.dumps(c))
-            new_row = pd.DataFrame(
-                {
-                    'Model': model_type,
-                    'ModelParameters': model_dicts,
-                    'TransformationParameters': trans_dicts,
-                    'Ensemble': 0,
-                },
-                index=list(range(n)),
+            new_template_list.append(
+                pd.DataFrame(
+                    {
+                        'Model': model_type,
+                        'ModelParameters': model_dicts,
+                        'TransformationParameters': trans_dicts,
+                        'Ensemble': 0,
+                    },
+                    index=list(range(n)),
+                )
             )
+        # models with params that cannot be mixed, just random mutations
         else:
-            current_ops = sorted_results[sorted_results['Model'] == model_type]
-            n = 3
             trans_dicts = _trans_dicts(
                 current_ops,
                 best=best,
                 n=n,
                 transformer_list=transformer_list,
                 transformer_max_depth=transformer_max_depth,
+                first_transformer=trans_params,
             )
             model_dicts = list()
+            c0 = json.loads(model_params)
             for _ in range(n):
-                c = ModelMonster(model_type).get_new_params(method=models_mode)
+                c = random.choice(
+                    [c0, ModelMonster(model_type).get_new_params(method=models_mode)]
+                )
                 model_dicts.append(json.dumps(c))
-            new_row = pd.DataFrame(
-                {
-                    'Model': model_type,
-                    'ModelParameters': model_dicts,
-                    'TransformationParameters': trans_dicts,
-                    'Ensemble': 0,
-                },
-                index=list(range(n)),
+            new_template_list.append(
+                pd.DataFrame(
+                    {
+                        'Model': model_type,
+                        'ModelParameters': model_dicts,
+                        'TransformationParameters': trans_dicts,
+                        'Ensemble': 0,
+                    },
+                    index=list(range(n)),
+                )
             )
-        new_template = pd.concat(
-            [new_template, new_row], axis=0, ignore_index=True, sort=False
-        )
+    new_template = pd.concat(new_template_list, axis=0, ignore_index=True, sort=False)
     """
     # recombination of transforms across models by shifting transforms
     recombination = sorted_results.tail(len(sorted_results.index) - 1).copy()
@@ -1787,8 +1895,21 @@ def NewGeneticTemplate(
     ).reset_index(drop=True)
     new_template = UniqueTemplates(
         sorted_results, new_template, selection_cols=template_cols
-    ).head(max_results)
-    return new_template
+    )
+    # enjoy the privilege
+    if new_template.shape[0] < max_results:
+        return new_template
+    else:
+        if max_results < 1:
+            return new_template.sample(
+                frac=max_results,
+                weights=np.log(np.arange(new_template.shape[0]) + 2)[::-1] + 1,
+            )
+        else:
+            return new_template.sample(
+                max_results,
+                weights=np.log(np.arange(new_template.shape[0]) + 2)[::-1] + 1,
+            )
 
 
 def validation_aggregation(validation_results):
@@ -2010,10 +2131,15 @@ def generate_score(
             A new starting template may also help. {repr(e)}"""
         )
 
-    return overall_score
+    return overall_score.astype(float)  # need to handle complex values (!)
 
 
-def generate_score_per_series(results_object, metric_weighting, total_validations):
+def generate_score_per_series(
+    results_object,
+    metric_weighting,
+    total_validations=1,
+    models_to_use=None,
+):
     """Score generation on per_series_metrics for ensembles."""
     mae_weighting = metric_weighting.get('mae_weighting', 0)
     rmse_weighting = metric_weighting.get('rmse_weighting', 0)
@@ -2028,19 +2154,18 @@ def generate_score_per_series(results_object, metric_weighting, total_validation
     if sum([mae_weighting, rmse_weighting, contour_weighting, spl_weighting]) == 0:
         mae_weighting = 1
 
-    mae_scaler = (
-        results_object.per_series_mae[results_object.per_series_mae != 0]
-        .min()
-        .fillna(1)
-    )
+    # there are problems when very small ~e-20 type number are in play
+    mae_scaler = results_object.per_series_mae[
+        results_object.per_series_mae != 0
+    ].round(20)
+    mae_scaler = mae_scaler[mae_scaler != 0].min().fillna(1)
     mae_score = results_object.per_series_mae / mae_scaler
     overall_score = mae_score * mae_weighting
     if rmse_weighting > 0:
-        rmse_scaler = (
-            results_object.per_series_rmse[results_object.per_series_rmse != 0]
-            .min()
-            .fillna(1)
-        )
+        rmse_scaler = results_object.per_series_rmse[
+            results_object.per_series_rmse.round(20) != 0
+        ].round(20)
+        rmse_scaler = rmse_scaler.min().fillna(1)
         rmse_score = results_object.per_series_rmse / rmse_scaler
         overall_score = overall_score + (rmse_score * rmse_weighting)
     if made_weighting > 0:
@@ -2122,12 +2247,15 @@ def generate_score_per_series(results_object, metric_weighting, total_validation
     # select only models run through all validations
     # run_count = temp.groupby(level=0).count().mean(axis=1)
     # models_to_use = run_count[run_count >= total_validations].index.tolist()
-    run_count = local_results[['Model', 'ID']].groupby("ID").count()
-    models_to_use = run_count[run_count['Model'] >= total_validations].index.tolist()
+    if models_to_use is None:
+        run_count = local_results[['Model', 'ID']].groupby("ID").count()
+        models_to_use = run_count[
+            run_count['Model'] >= total_validations
+        ].index.tolist()
     overall_score = overall_score[overall_score.index.isin(models_to_use)]
     # take the average score across validations
     overall_score = overall_score.groupby(level=0).mean()
-    return overall_score
+    return overall_score.astype(float)  # need to handle complex values (!)
 
 
 def back_forecast(
