@@ -32,40 +32,42 @@ all_models = [
     'ARDL',
     'NeuralProphet',
     'DynamicFactorMQ',
+    'PytorchForecasting',
+    'ARCH',
 ]
-default = [
-    'ConstantNaive',
-    'LastValueNaive',
-    'AverageValueNaive',
-    'GLS',
-    'SeasonalNaive',
-    'GLM',
-    'ETS',
-    'FBProphet',
-    # 'RollingRegression',  # maybe not?
-    # 'GluonTS',  # downweight if that becomes an option
-    'UnobservedComponents',
-    'VAR',
-    'VECM',
-    'WindowRegression',
-    'DatepartRegression',
-    # 'UnivariateRegression',  # this has been crashing on 1135
-    'MultivariateRegression',  # downweight if that becomes an option
-    'UnivariateMotif',
-    'MultivariateMotif',
-    'SectionalMotif',
-    'NVAR',
-    'Theta',
-    'ARDL',
-    # 'DynamicFactorMQ',
-]
+# downweight slower models
+default = {
+    'ConstantNaive': 1,
+    'LastValueNaive': 1,
+    'AverageValueNaive': 1,
+    'GLS': 1,
+    'SeasonalNaive': 1,
+    'GLM': 1,
+    'ETS': 1,
+    'FBProphet': 0.5,
+    # 'RollingRegression': 1,  # maybe not?
+    'GluonTS': 0.5,  # downweight if that becomes an option
+    'UnobservedComponents': 1,
+    'VAR': 1,
+    'VECM': 1,
+    'WindowRegression': 0.5,
+    'DatepartRegression': 1,
+    'UnivariateRegression': 0.2,
+    'MultivariateRegression': 0.2,
+    'UnivariateMotif': 1,
+    'MultivariateMotif': 1,
+    'SectionalMotif': 1,
+    'NVAR': 1,
+    'Theta': 1,
+    'ARDL': 1,
+    # 'DynamicFactorMQ': 1,
+}
 best = [
     'LastValueNaive',
     'AverageValueNaive',
     'GLS',
     'GLM',
     'ETS',
-    # 'ARIMA',
     'FBProphet',
     # 'RollingRegression',
     'GluonTS',
@@ -95,39 +97,40 @@ superfast = [
     'SeasonalNaive',
 ]
 # relatively fast
-fast = [
-    'ConstantNaive',
-    'LastValueNaive',
-    'AverageValueNaive',
-    'GLS',
-    'SeasonalNaive',
-    'GLM',
-    'ETS',
-    # 'UnobservedComponents',  # it's fast enough but I'll leave for parallel
-    'VAR',
-    'VECM',
-    'WindowRegression',  # well, this gets slow with Transformer, KerasRNN
-    'DatepartRegression',
-    'UnivariateMotif',
-    'MultivariateMotif',
-    'SectionalMotif',
-    'NVAR',
-]
+fast = {
+    'ConstantNaive': 1,
+    'LastValueNaive': 1.5,
+    'AverageValueNaive': 1,
+    'GLS': 1,
+    'SeasonalNaive': 1,
+    'GLM': 1,
+    'ETS': 1,
+    # 'UnobservedComponents': 1,  # it's fast enough but I'll leave for parallel
+    'VAR': 0.8,
+    'VECM': 1,
+    'WindowRegression': 0.5,  # this gets slow with Transformer, KerasRNN
+    'DatepartRegression': 0.8,
+    'UnivariateMotif': 1,
+    'MultivariateMotif': 0.8,
+    'SectionalMotif': 1,
+    'NVAR': 1,
+}
 # models that can scale well if many CPU cores are available
-parallel = [
-    'ETS',
-    'FBProphet',
-    'ARIMA',
-    'GLM',
-    'UnobservedComponents',
-    "Greykite",
-    'UnivariateMotif',
-    'MultivariateMotif',
-    'Theta',
-    'ARDL',
-]
+parallel = {
+    'ETS': 1,
+    'FBProphet': 0.8,
+    'ARIMA': 1,
+    'GLM': 1,
+    'UnobservedComponents': 1,
+    "Greykite": 0.3,
+    'UnivariateMotif': 1,
+    'MultivariateMotif': 1,
+    'Theta': 1,
+    'ARDL': 1,
+    'ARCH': 1,
+}
 # models that should be fast given many CPU cores
-fast_parallel = list(set(parallel + fast))
+fast_parallel = {**parallel, **fast}
 # models that are explicitly not production ready
 experimental = [
     'MotifSimulation',
@@ -136,9 +139,9 @@ experimental = [
     'TFPRegression',
 ]
 # models that perform slowly at scale
-slow = list((set(all_models) - set(fast)) - set(experimental))
+slow = list((set(all_models) - set(fast.keys())) - set(experimental))
 # use GPU
-gpu = ['GluonTS', 'WindowRegression']
+gpu = ['GluonTS', 'WindowRegression', 'PytorchForecasting']
 # models with model-based upper/lower forecasts
 probabilistic = [
     'ARIMA',
@@ -156,7 +159,9 @@ probabilistic = [
     'ARDL',
     'UnobservedComponents',
     'DynamicFactorMQ',
+    'PytorchForecasting',
     # 'MultivariateRegression',
+    'ARCH',
 ]
 # models that use the shared information of multiple series to improve accuracy
 multivariate = [
@@ -172,6 +177,7 @@ multivariate = [
     'MultivariateRegression',
     'SectionalMotif',
     'DynamicFactorMQ',
+    'PytorchForecasting',
 ]
 univariate = list((set(all_models) - set(multivariate)) - set(experimental))
 # USED IN AUTO_MODEL, models with no parameters
@@ -204,6 +210,8 @@ recombination_approved = [
     'ARDL',
     'NeuralProphet',
     'DynamicFactorMQ',
+    'PytorchForecasting',
+    'ARCH',
 ]
 # USED IN AUTO_MODEL for models that don't share information among series
 no_shared = [
@@ -224,6 +232,7 @@ no_shared = [
     'Theta',
     'ARDL',
     'NeuralProphet',
+    'ARCH',
 ]
 # allow the use of a regressor, need to accept "User" (fail if not given), have 'regressor' param method
 regressor = [
@@ -243,6 +252,13 @@ regressor = [
     'SectionalMotif',  # kinda
     'ARDL',
     'NeuralProphet',
+    'ARCH',
+]
+motifs = [
+    'UnivariateMotif',
+    "MultivariateMotif",
+    'SectionalMotif',
+    'MotifSimulation',
 ]
 no_shared_fast = list(set(no_shared).intersection(set(fast_parallel)))
 model_lists = {
@@ -264,6 +280,7 @@ model_lists = {
     "gpu": gpu,
     "regressor": regressor,
     "best": best,
+    "motifs": motifs,
 }
 
 
